/*************************************************************************

"FreePastry" Peer-to-Peer Application Development Substrate 

Copyright 2002, Rice University. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

- Neither  the name  of Rice  University (RICE) nor  the names  of its
contributors may be  used to endorse or promote  products derived from
this software without specific prior written permission.

This software is provided by RICE and the contributors on an "as is"
basis, without any representations or warranties of any kind, express
or implied including, but not limited to, representations or
warranties of non-infringement, merchantability or fitness for a
particular purpose. In no event shall RICE or contributors be liable
for any direct, indirect, incidental, special, exemplary, or
consequential damages (including, but not limited to, procurement of
substitute goods or services; loss of use, data, or profits; or
business interruption) however caused and on any theory of liability,
whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even
if advised of the possibility of such damage.

********************************************************************************/
package rice.p2p.aggregation;

import java.io.IOException;

import rice.p2p.commonapi.*;
import rice.p2p.commonapi.rawserialization.*;
import rice.p2p.past.*;
import rice.p2p.past.gc.*;
import rice.p2p.past.gc.rawserialization.RawGCPastContentHandle;

public class AggregateHandle implements RawGCPastContentHandle {

  public static final short TYPE = 1;
  
  protected Id id;
  protected NodeHandle handle;
  protected long version;
  protected long expiration;

  public AggregateHandle(NodeHandle handle, Id id, long version, long expiration) {
    this.id = id;
    this.handle = handle;
    this.version = version;
    this.expiration = expiration;
  }

  public Id getId() {
    return id;
  }

  public NodeHandle getNodeHandle() {
    return handle;
  }

  public long getVersion() {
    return version;
  }

  public long getExpiration() {
    return expiration;
  }

  public short getType() {
    return TYPE;
  }
  
  public AggregateHandle(InputBuffer buf, Endpoint endpoint) throws IOException {
    version = buf.readLong();
    expiration = buf.readLong();
    id = endpoint.readId(buf, buf.readShort());
    handle = endpoint.readNodeHandle(buf);
  }

  public void serialize(OutputBuffer buf) throws IOException {
    buf.writeLong(version);
    buf.writeLong(expiration);
    buf.writeShort(id.getType());
    id.serialize(buf);
    handle.serialize(buf);
  }
}

